import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:zhiying_base_widget/pages/goods_share_page/goods_share_image/goods_share_image.dart';
import 'package:zhiying_base_widget/pages/goods_share_page/goods_share_link/goods_share_link.dart';
import 'package:zhiying_base_widget/pages/goods_share_page/goods_share_miniprogram/goods_share_miniprogram.dart';
import 'package:zhiying_base_widget/pages/goods_share_page/widgets/goods_share_alert_content.dart';
import 'package:zhiying_base_widget/widgets/share/share_alert.dart';
import 'package:zhiying_comm/zhiying_comm.dart';

class GoodsSharePage extends StatefulWidget {
  @override
  _GoodsSharePageState createState() => _GoodsSharePageState();
}

class _GoodsSharePageState extends State<GoodsSharePage>
    with TickerProviderStateMixin {
  TabController _tabController;
  List<Widget> _tabs;
  List<Widget> _contents;

  @override
  void initState() {
    _tabController = TabController(length: 3, vsync: this);
    _tabs = [
      _createTabItem('分享图文'),
      _createTabItem('分享链接'),
      _createTabItem('分享小程序'),
    ];
    _contents = [
      GoodsShareImage(),
      GoodsShareLink(),
      GoodsShareMiniprogram(),
    ];
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Color(0xfff8f8f8),
      appBar: _createNav(),
      body: Column(
        children: <Widget>[
          _createCommission(),
          Expanded(child: _createContent()),
          _createBottom(),
        ],
      ),
    );
  }

  // 导航栏
  Widget _createNav() {
    return CupertinoNavigationBar(
      border: Border(
        bottom: BorderSide(
          width: 0.0, // One physical pixel.
          style: BorderStyle.none,
        ),
      ),
      // backgroundColor: HexColor.fromHex('#ffffff'),
      leading: Navigator.canPop(context)
          ? GestureDetector(
              child: Container(
                padding: EdgeInsets.zero,
                child: Icon(
                  Icons.arrow_back_ios,
                  size: 20,
                ),
              ),
              onTap: () {
                if (Navigator.canPop(context)) {
                  Navigator.pop(context);
                }
              },
            )
          : Container(),
      middle: Text(
        '分享商品',
        style: TextStyle(
          fontSize: 15,
          color: HexColor.fromHex('#333333'),
        ),
      ),
    );
  }

  Widget _createCommission() {
    return Container(
      margin: EdgeInsets.only(left: 12.5, right: 12.5, top: 4, bottom: 4),
      padding: EdgeInsets.only(left: 10, right: 10),
      width: double.infinity,
      height: 32,
      decoration: BoxDecoration(
          color: Colors.white, borderRadius: BorderRadius.circular(8)),
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.center,
        children: <Widget>[
          Container(
            width: 20,
            height: 20,
            margin: EdgeInsets.only(right: 10),
            decoration: BoxDecoration(
                color: Colors.redAccent,
                borderRadius: BorderRadius.circular(10)),
          ),
          Text(
            '奖励预估收益 ¥ 12.35 元',
            style: TextStyle(
                fontSize: 13,
                fontWeight: FontWeight.bold,
                color: Color(0xff333333)),
          ),
        ],
      ),
    );
  }

  Widget _createContent() {
    return Container(
      margin: EdgeInsets.only(left: 12.5, right: 12.5, top: 4, bottom: 4),
      width: double.infinity,
      height: double.infinity,
      decoration: BoxDecoration(
          color: Colors.white, borderRadius: BorderRadius.circular(8)),
      child: Column(
        children: <Widget>[
          Container(
            height: 40,
            width: double.infinity,
            child: TabBar(
              controller: _tabController,
              tabs: _tabs,
              indicatorColor: Color(0xffff4242),
              indicatorSize: TabBarIndicatorSize.label,
            ),
          ),
          Expanded(
            child: TabBarView(
              controller: _tabController,
              children: _contents,
            ),
          )
        ],
      ),
    );
  }

  Widget _createBottom() {
    return SafeArea(
      child: Container(
        margin: EdgeInsets.only(left: 12.5, right: 12.5, top: 4, bottom: 4),
        child: Row(
          children: <Widget>[
            Container(
              width: 95,
              height: 36,
              decoration: BoxDecoration(
                color: Colors.red,
                borderRadius: BorderRadius.circular(18),
              ),
              child: Center(
                child: Text(
                  '仅复制口令',
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ),
            Container(
              margin: EdgeInsets.only(left: 5),
              width: 95,
              height: 36,
              decoration: BoxDecoration(
                color: Colors.orangeAccent,
                borderRadius: BorderRadius.circular(18),
              ),
              child: Center(
                child: Text(
                  '保存选图',
                  style: TextStyle(color: Colors.white),
                ),
              ),
            ),
            Expanded(
              child: GestureDetector(
                child: Container(
                  margin: EdgeInsets.only(left: 5),
                  // width: 95,
                  height: 36,
                  decoration: BoxDecoration(
                    color: Colors.amber,
                    borderRadius: BorderRadius.circular(18),
                  ),
                  child: Center(
                    child: Text(
                      '分享选中素材',
                      style: TextStyle(color: Colors.white),
                    ),
                  ),
                ),
                onTap: () {
                  _showShare();
                },
              ),
            ),
          ],
        ),
      ),
    );
  }

  Widget _createTabItem(String title, {bool isSelected = false}) {
    return Text(
      title,
      style: TextStyle(
        fontSize: 13,
        color: isSelected ? Color(0xffff4242) : Color(0xff333333),
        fontWeight: FontWeight.bold,
      ),
    );
  }

  void _showShare() async {
    showCupertinoModalPopup(
      context: context,
      builder: (context) => ShareAlert(
        child: GoodsShareAlertContent(),
      ),
    );
  }
}
